"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var DateInput_model_1 = require("../DateInput.model");
var Option_1 = require("fp-ts/lib/Option");
var Array_1 = require("fp-ts/lib/Array");
var pipeable_1 = require("fp-ts/lib/pipeable");
describe('date input', function () {
    describe('decrement month', function () {
        var months = [-1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12];
        var expextedMonths = [11, 11, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11];
        it('should decrement month or return default value', function () {
            var newMonths = months.map(function (month) { return DateInput_model_1.decrementMonth(month); });
            expect(newMonths).toEqual(expextedMonths);
        });
        it('should decrement month or return default value (works with option)', function () {
            var newMonths = Array_1.array.sequence(Option_1.option)(months.map(function (month) { return DateInput_model_1.decrementMonthOption(Option_1.some(month)); }));
            pipeable_1.pipe(newMonths, Option_1.map(function (value) { return expect(value).toEqual(expextedMonths); }));
            var defaultOptionMonth = Option_1.some(11);
            var noneMonth = DateInput_model_1.decrementMonthOption(Option_1.none);
            pipeable_1.pipe(noneMonth, Option_1.chain(function (noneMonth) { return pipeable_1.pipe(defaultOptionMonth, Option_1.map(function (month) { return expect(noneMonth).toBe(month); })); }));
        });
    });
    describe('increment month', function () {
        var months = [-1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12];
        var expextedMonths = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 0, 0];
        it('should increment month or return default value', function () {
            var newMonths = months.map(function (month) { return DateInput_model_1.incrementMonth(month); });
            expect(newMonths).toEqual(expextedMonths);
        });
        it('should increment month or return default value (works with option)', function () {
            var newMonths = Array_1.array.sequence(Option_1.option)(months.map(function (month) { return DateInput_model_1.incrementMonthOption(Option_1.some(month)); }));
            pipeable_1.pipe(newMonths, Option_1.map(function (value) { return expect(value).toEqual(expextedMonths); }));
            var defaultOptionMonth = Option_1.some(0);
            var noneMonth = DateInput_model_1.incrementMonthOption(Option_1.none);
            pipeable_1.pipe(noneMonth, Option_1.chain(function (noneMonth) { return pipeable_1.pipe(defaultOptionMonth, Option_1.map(function (month) { return expect(noneMonth).toBe(month); })); }));
        });
    });
});
//# sourceMappingURL=dateInput.test.js.map